@@ -2,7 +2,7 @@
  * GChemPaint GOffice component
  * gofficeapp.h
  *
- * Copyright (C) 2005-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -35,19 +35,15 @@ public:
 	virtual ~gcpGOfficeApplication ();
 
 	virtual GtkWindow* GetWindow();
-	virtual void RemoveDocument(gcpDocument* pDoc);
 	virtual void ToggleMenu(const string& menuname, bool active);
 
 	gcpDocument *ImportDocument (const string& mime_type, const char* data, int length);
 	bool EditDocument (GOGChemPaintComponent *gogcp);
 
-	void OnFileNew ();
+	void OnFileNew (char const *Theme = NULL);
 	void OnFileClose ();
 
-protected:
-	virtual void AddDocument (gcpDocument *pDoc);
-
-private:
+	void NoMoreDocsEvent () {;}
 
 private:
 	map<gcpDocument *, gpointer> m_Windows;
