@@ -40,6 +40,7 @@
 #include <openbabel/mol.h>
 #include <glib/gi18n-lib.h>
 #include <cmath>
+#include <cstring>
 
 using namespace gcu;
 
@@ -586,6 +587,8 @@ void gcpAtom::Update(GtkWidget* w)
 {
 	if (!w) return;
 	gcpWidgetData* pData = (gcpWidgetData*)g_object_get_data(G_OBJECT(w), "data");
+	if (pData->Items[this] != NULL)
+		return;
 	gcpTheme *pTheme = pData->View->GetDoc ()->GetTheme ();
 	double x, y, xc = 0., yc;
 	GetCoords(&x, &y);
