@@ -38,6 +38,7 @@
 #include "libgcpcanvas/gcp-canvas-polygon.h"
 #include <glib/gi18n-lib.h>
 #include <cmath>
+#include <cstring>
 
 gcpBond::gcpBond(): Bond()
 {
@@ -713,6 +714,8 @@ void gcpBond::Update(GtkWidget* w)
 	if (!w || !m_order)
 		return;
 	gcpWidgetData* pData = (gcpWidgetData*) g_object_get_data(G_OBJECT(w), "data");
+	if (pData->Items[this] != NULL)
+		return;
 	gcpTheme *pTheme = pData->View->GetDoc ()->GetTheme ();
 	bool result = false;
 	if (m_Crossing.size () > 0) {
